@@ -8,7 +8,7 @@ import zlib
 
 import pkg_resources
 
-from . import async
+from . import async_reader
 from . import audio
 from . import calib
 from . import main
@@ -31,7 +31,7 @@ bitrate = os.environ.get('BITRATE', 1)
 config = bitrates.get(int(bitrate))
 
 
-class Compressor(object):
+class Compressor:
     def __init__(self, stream):
         self.obj = zlib.compressobj()
         log.info('Using zlib compressor')
@@ -52,7 +52,7 @@ class Compressor(object):
             return result
 
 
-class Decompressor(object):
+class Decompressor:
     def __init__(self, stream):
         self.obj = zlib.decompressobj()
         log.info('Using zlib decompressor')
@@ -77,7 +77,7 @@ def FileType(mode, interface_factory=None):
             assert audio_interface is not None
             if 'r' in mode:
                 s = audio_interface.recorder()
-                return async.AsyncReader(stream=s, bufsize=s.bufsize)
+                return async_reader.AsyncReader(stream=s, bufsize=s.bufsize)
             if 'w' in mode:
                 return audio_interface.player()
 
@@ -124,10 +124,13 @@ def create_parser(description, interface_factory):
     sender.add_argument(
         '-g', '--gain', type=float, default=1.0,
         help='Modulator gain (defaults to 1)')
+    sender.add_argument(
+        '--silence', type=float, default=0.0,
+        help='Extra silence before sending the data (in seconds)')
     sender.set_defaults(
         main=lambda config, args: main.send(
             config, src=wrap(Compressor, args.src, args.zlib), dst=args.dst,
-            gain=args.gain
+            gain=args.gain, extra_silence=args.silence
         ),
         calib=lambda config, args: calib.send(
             config=config, dst=args.dst,
@@ -142,8 +145,7 @@ def create_parser(description, interface_factory):
     receiver = subparsers.add_parser(
         'recv', help='demodulate audio signal into binary data.')
     receiver.add_argument(
-        '-i', '--input', help='input file (use "-" for stdin).'
-        ' if not specified, `arecord` tool will be used.')
+        '-i', '--input', help='input file (use "-" for stdin).')
     receiver.add_argument(
         '-o', '--output', help='output file (use "-" for stdout).')
     receiver.add_argument(
@@ -186,7 +188,7 @@ def create_parser(description, interface_factory):
     return p
 
 
-class _Dummy(object):
+class _Dummy:
     def __enter__(self):
         return self
 
@@ -198,6 +200,20 @@ def _version():
     return pkg_resources.require('amodem')[0].version
 
 
+def _config_log(args):
+    if args.verbose == 0:
+        level, fmt = 'INFO', '%(message)s'
+    elif args.verbose == 1:
+        level, fmt = 'DEBUG', '%(message)s'
+    elif args.verbose >= 2:
+        level, fmt = ('DEBUG', '%(asctime)s %(levelname)-10s '
+                               '%(message)-100s '
+                               '%(filename)s:%(lineno)d')
+    if args.quiet:
+        level, fmt = 'WARNING', '%(message)s'
+    logging.basicConfig(level=level, format=fmt)
+
+
 def _main():
     fmt = ('Audio OFDM MODEM v{0:s}: '
            '{1:.1f} kb/s ({2:d}-QAM x {3:d} carriers) '
@@ -213,31 +229,25 @@ def _main():
     p = create_parser(description, interface_factory)
 
     args = p.parse_args()
-    if args.verbose == 0:
-        level, fmt = 'INFO', '%(message)s'
-    elif args.verbose == 1:
-        level, fmt = 'DEBUG', '%(message)s'
-    elif args.verbose >= 2:
-        level, fmt = ('DEBUG', '%(asctime)s %(levelname)-10s '
-                               '%(message)-100s '
-                               '%(filename)s:%(lineno)d')
-    if args.quiet:
-        level, fmt = 'WARNING', '%(message)s'
-    logging.basicConfig(level=level, format=fmt)
+    _config_log(args)
 
     # Parsing and execution
-    log.debug(description)
+    log.info(description)
 
     args.pylab = None
     if getattr(args, 'plot', False):
-        import pylab  # pylint: disable=import-error
+        import pylab  # pylint: disable=import-error,import-outside-toplevel
         args.pylab = pylab
 
     if args.audio_library == 'ALSA':
-        from . import alsa
+        from . import alsa  # pylint: disable=import-outside-toplevel
         interface = alsa.Interface(config)
     elif args.audio_library == '-':
-        interface = _Dummy()
+        interface = _Dummy()  # manually disable PortAudio
+    elif args.command == 'send' and args.output is not None:
+        interface = _Dummy()  # redirected output
+    elif args.command == 'recv' and args.input is not None:
+        interface = _Dummy()  # redirected input
     else:
         interface = audio.Interface(config)
         interface.load(args.audio_library)
