@@ -1,7 +1,7 @@
 import time
 
 
-class Reader(object):
+class Reader:
 
     wait = 0.2
     timeout = 2.0
@@ -24,8 +24,7 @@ class Reader(object):
                 self.total += len(data)
                 block.extend(data)
                 return block
-            else:
-                raise StopIteration()
+            raise StopIteration()
 
         finish_time = time.time() + self.timeout
         while time.time() <= finish_time:
@@ -45,7 +44,7 @@ class Reader(object):
     __next__ = next
 
 
-class Dumper(object):
+class Dumper:
     def __init__(self, src, dst):
         self.src = src
         self.dst = dst
